@@ -7,11 +7,13 @@ import pandas as pd
 import pickle
 import warnings
 
-sys.path.insert(0, str(Path(__file__).parent.parent.parent))
+# Add src to path for imports
+project_root = Path(__file__).parent.parent.parent
+sys.path.insert(0, str(project_root / 'src'))
 
-from src.nowcasting.dfm import dfm, DFMResult, em_step, init_conditions
-from src.nowcasting.data_loader import load_config, load_data
-from src.utils.data_utils import rem_nans_spline
+from dfm_python.dfm import dfm, DFMResult, em_step, init_conditions
+from dfm_python.data_loader import load_config, load_data
+from utils.data_utils import rem_nans_spline
 
 try:
     from scipy.io import loadmat
