@@ -9,7 +9,11 @@ import warnings
 
 sys.path.insert(0, str(Path(__file__).parent.parent.parent))
 
-from src.nowcasting import load_config, load_data, dfm, update_nowcast
+# Add src to path for imports
+project_root = Path(__file__).parent.parent.parent
+sys.path.insert(0, str(project_root / 'src'))
+
+from dfm_python import load_config, load_data, dfm, update_nowcast
 
 def _get_spec_and_data():
     """Load specification and data."""
